Learn R Programming

iPRISM (version 0.1.1)

genelist_cp: TME gene list after random walks

Description

This gene list includes genes from tumor microenvironment (TME). Random Walk with Restart (RWR) is applied to prioritize genes that are relevant to immunotherapy responses.

Usage

genelist_cp

Arguments

Format

An object of class numeric of length 15867.

Examples

Run this code
library(iPRISM)
data(genelist_cp, package = "iPRISM")

Run the code above in your browser using DataLab