Learn R Programming

iPRISM (version 0.1.1)

genelist_hla: HLA gene list after random walks

Description

This gene list includes genes from human leukocyte antigen (HLA). Random Walk with Restart (RWR) is applied to prioritize genes that are relevant to immunotherapy responses.

Usage

genelist_hla

Arguments

Format

An object of class numeric of length 15867.

Examples

Run this code
library(iPRISM)
data(genelist_hla, package = "iPRISM")

Run the code above in your browser using DataLab