powered by
This gene list includes genes from tumor microenvironment (TME). Random Walk with Restart (RWR) is applied to prioritize genes that are relevant to immunotherapy responses.
genelist_cp
An object of class numeric of length 15867.
numeric
library(iPRISM) data(genelist_cp, package = "iPRISM")
Run the code above in your browser using DataLab